@@ -10,8 +10,10 @@ RSpec.describe ProcessExecuter::MonitoredPipe do
   context 'when used to wrap an output destination for Process.spawn' do
     context 'when the output destination is nil' do
       let(:destination) { nil }
-      it 'should raise an ArgumentError' do
-        expect { ProcessExecuter::MonitoredPipe.new(nil) }.to raise_error(ArgumentError, 'wrong exec redirect action')
+      it 'should raise an ProcessExecuter::ArgumentError' do
+        expect { ProcessExecuter::MonitoredPipe.new(nil) }.to(
+          raise_error(ProcessExecuter::ArgumentError, 'Destination nil is not compatible with MonitoredPipe')
+        )
       end
     end
 
@@ -160,9 +162,9 @@ RSpec.describe ProcessExecuter::MonitoredPipe do
 
     context 'when the output destination is an array in the form [filepath]' do
       # [filepath] only works for stdin
-      it 'should raise an ArgumentError' do
+      it 'should raise an ProcessExecuter::ArgumentError' do
         expect { ProcessExecuter::MonitoredPipe.new(['filepath']) }.to(
-          raise_error(ArgumentError, 'wrong exec redirect action')
+          raise_error(ProcessExecuter::ArgumentError, 'Destination ["filepath"] is not compatible with MonitoredPipe')
         )
       end
     end
@@ -177,7 +179,7 @@ RSpec.describe ProcessExecuter::MonitoredPipe do
           ProcessExecuter::MonitoredPipe.assert_no_open_instances
         end
 
-        it 'should raise an ArgumentError' do
+        it 'the exception methods should note that an IOError was raised' do
           command = ruby_command(<<~COMMAND)
             puts 'stdout output'
           COMMAND
@@ -419,18 +421,18 @@ RSpec.describe ProcessExecuter::MonitoredPipe do
 
     context 'when the output destination is an array in the form [:child, fd]' do
       # redirect the source to the destination fd in the child process
-      it 'should raise an error' do
+      it 'should raise a ProcessExecuter::ArgumentError' do
         expect { ProcessExecuter::MonitoredPipe.new([:child, 1]) }.to(
-          raise_error(ArgumentError, 'Destination [:child, 1] is not compatible with MonitoredPipe')
+          raise_error(ProcessExecuter::ArgumentError, 'Destination [:child, 1] is not compatible with MonitoredPipe')
         )
       end
     end
 
     context 'when the output destination is :close' do
       # close the fd in the child process
-      it 'should raise an error' do
+      it 'should raise a ProcessExecuter::ArgumentError' do
         expect { ProcessExecuter::MonitoredPipe.new(:close) }.to(
-          raise_error(ArgumentError, 'wrong exec redirect action')
+          raise_error(ProcessExecuter::ArgumentError, 'Destination :close is not compatible with MonitoredPipe')
         )
       end
     end
@@ -502,7 +504,7 @@ RSpec.describe ProcessExecuter::MonitoredPipe do
     it 'should create a new monitored pipe' do
       expect(monitored_pipe).to have_attributes(
         thread: Thread,
-        destination: ProcessExecuter::DestinationBase,
+        destination: ProcessExecuter::Destinations::DestinationBase,
         pipe_reader: IO,
         pipe_writer: IO,
         chunk_size: Integer
@@ -742,4 +744,28 @@ RSpec.describe ProcessExecuter::MonitoredPipe do
       end
     end
   end
+
+  describe 'encoding of output' do
+    let(:output_writer) do
+      Class.new do
+        def initialize
+          @data = []
+        end
+
+        attr_reader :data
+
+        def write(new_data)
+          @data << new_data
+        end
+      end.new
+    end
+
+    it 'should write data with BINARY encoding' do
+      monitored_pipe.write('違いを生み出すサンプルテキスト'.encode(Encoding::UTF_8))
+      sleep(0.01)
+      monitored_pipe.close
+      expect(output_writer.data.size).to eq(1)
+      expect(output_writer.data).to all(satisfy { |d| d.encoding == Encoding::BINARY })
+    end
+  end
 end
